/*
 *	Copyright 1999, Be Incorporated. All Rights Reserved.
 *	This file may be used under the terms of the Be Sample Code License.
 */

#include <Application.h>
#include <FindDirectory.h>
#include <TranslationUtils.h>
#include <String.h>
#include <Path.h>
#include <Screen.h>


#include <fcntl.h>
#include <unistd.h>
#include <sys/stat.h>
#include <stdio.h>

#include "izmena_resizer.h"
#include "test_window.h"


TestView::TestView(BRect rect, const char *title)
	: BView(rect, title, B_FOLLOW_ALL_SIDES, B_WILL_DRAW | B_DRAW_ON_CHILDREN)
{
	zoom = 1.0;
	fBitmap = NULL;
	fBitmapSized = NULL;
	
	SetViewColor(220,220,220);
}

TestView::~TestView() {}

void
TestView::Draw(BRect rect)
{
	if(fBitmapSized) {
		DrawBitmap(fBitmapSized);
	}
}


void
TestView::SetBitmap(BBitmap *bmp)
{
	if(fBitmap) {
			BBitmap *tmp = fBitmap;
			fBitmap = bmp;			
			delete tmp;
	} else {
			fBitmap = bmp;
	}
	RescaleBitmap();	
}

void
TestView::SetZoom(float z)
{
	zoom = z;
	RescaleBitmap();
	Invalidate();
}

float	
TestView::Zoom(void)
{
	return zoom;
}

void 
TestView::RescaleBitmap(void)
{
	if(fBitmap) {
		BRect r(0, 0, fBitmap->Bounds().Width()*zoom, fBitmap->Bounds().Height()*zoom);
		BBitmap *newbmp = new BBitmap(r, B_RGB32);
		ResizeBitmap(fBitmap,newbmp);
		if(fBitmapSized) {
			BBitmap *tmp = fBitmapSized;
			fBitmapSized = newbmp;			
			delete tmp;
		} else {
			fBitmapSized = newbmp;
		}
	}
}


TestWindow::TestWindow(BRect frame, const char* title)
	: BWindow(frame, title, B_TITLED_WINDOW_LOOK,B_NORMAL_WINDOW_FEEL,0),
fView(NULL)
{
	_InitWindow();
}


TestWindow::~TestWindow()
{
}

void 
TestWindow::SetBitmap(BBitmap *bmp)
{
	fView->SetBitmap(bmp);
}

bool
TestWindow::QuitRequested()
{
	be_app->PostMessage(B_QUIT_REQUESTED);
	return true;
}

void 
TestWindow::MessageReceived(BMessage *message)
{
	switch (message->what) {
		case B_KEY_DOWN:
		{
			uint32 code = message->FindInt32("key") & 0xff;
			if(code==58) {
     	 		fView->SetZoom(fView->Zoom()*1.1);     	 		
     	 	}
     	 	if(code==37) {
     	 		fView->SetZoom(fView->Zoom()*0.9);
     	 	}     	      	 
			break;
		}		
		default:
			BWindow::MessageReceived(message);
			break;
	}
}
void
TestWindow::_InitWindow()
{
	fView = new TestView(Bounds(),"view");
	AddChild(fView);
}

